==> haskell-tasty-discover-5.0.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.0/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-discover
version:              5.0.0
visibility:           public
id:                   tasty-discover-5.0.0-9i3Xhi4dC3S7VsItvdegNq
key:                  tasty-discover-5.0.0-9i3Xhi4dC3S7VsItvdegNq
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  5995893585529504951ef93daaa27b1a
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-discover-5.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-discover-5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.0-9i3Xhi4dC3S7VsItvdegNq
depends:
    Glob-0.10.2-IV3EMKztTxU6CHYEAa9DJ0 base-4.16.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    tasty-1.4.3-B04wakHanaTFmtNBHSmYAO

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-discover-5.0.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-discover.sh <==
#!/bin/sh
export PATH='/build/haskell-tasty-discover/src/tasty-discover-5.0.0/dist/build/tasty-discover:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-discover
version:              5.0.0
visibility:           public
id:                   tasty-discover-5.0.0-13CkbYemJax84lYQx3ceXw
key:                  tasty-discover-5.0.0-13CkbYemJax84lYQx3ceXw
license:              MIT
copyright:
    2016 Luke Murphy
    2020-2022 John Ky

maintainer:           John Ky <newhoggy@gmail.com>
author:               Luke Murphy
stability:            Experimental
homepage:             https://github.com/haskell-works/tasty-discover
synopsis:             Test discovery for the tasty framework.
description:
    Automatic test discovery and runner for the tasty framework.
    Prefix your test case names and tasty-discover will discover, collect and run them.
    All popular test libraries are covered. Configure once and then just write your tests.
    Avoid forgetting to add test modules to your Cabal/Hpack files.
    Tasty ingredients are included along with various configuration options for different
    use cases.
    Please see the `README.md` below for how to get started.

category:             Testing
abi:                  8d7714edc92d58de89f9e3832217a62d
exposed:              True
exposed-modules:
    Test.Tasty.Discover Test.Tasty.Discover.Internal.Config
    Test.Tasty.Discover.Internal.Driver
    Test.Tasty.Discover.Internal.Generator
    Test.Tasty.Discover.TastyInfo Test.Tasty.Discover.Version

hidden-modules:       Paths_tasty_discover
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tasty-discover-5.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tasty-discover-5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-discover
hs-libraries:         HStasty-discover-5.0.0-13CkbYemJax84lYQx3ceXw
depends:
    Glob-0.10.2-IV3EMKztTxU6CHYEAa9DJ0 base-4.16.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    tasty-1.4.3-B04wakHanaTFmtNBHSmYAO

haddock-interfaces:
    /usr/share/doc/haskell-tasty-discover/html/tasty-discover.haddock

haddock-html:         /usr/share/doc/haskell-tasty-discover/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
